@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: alert.c,v 1.96 2005/10/20 20:12:59 gstueve Exp $
+ * $Id: alert.c,v 1.104 2007/02/27 21:33:03 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -284,7 +284,9 @@
 
 
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -650,7 +652,7 @@ static time_t last_alert_expire = 0;
 //
 // Returns the quantity of alerts that were just expired.
 //
-int alert_expire(void) {
+int alert_expire(int curr_sec) {
 //    int ii;
     int expire_count = 0;
     struct hashtable_itr *iterator;
@@ -658,10 +660,10 @@ int alert_expire(void) {
 
 
     // Check only every 60 seconds
-    if ( (last_alert_expire + 60) > sec_now() ) {
+    if ( (last_alert_expire + 60) > curr_sec ) {
         return(0);
     }
-    last_alert_expire = sec_now();
+    last_alert_expire = curr_sec;
 
     if (debug_level & 2)
         fprintf(stderr,"Checking for expired alerts...\n");
@@ -1058,7 +1060,7 @@ void alert_build_list(Message *fill) {
     }
 
     // Empty this string first
-    uncompressed_wx[0] = '\0';
+    uncompressed_wx[0] = uncompressed_wx[1] = '\0';
 
     // Check for "SKY" text in the "call_sign" field.
     if (strncmp(fill->call_sign,"SKY",3) == 0) {
@@ -1194,7 +1196,8 @@ void alert_build_list(Message *fill) {
                 &title[4][0]);       // ...
 
         if (ret < 3)
-          fprintf(stderr,"sscanf parsed %d values in alert.c (3-7 ok) %s, %s\n", ret, fill->from_call_sign, fill->message_line);
+          fprintf(stderr,"sscanf parsed %d values in alert.c (3-7 ok) %s->%s: %s\n", ret, 
+			fill->from_call_sign, fill->call_sign, fill->message_line);
 
         // Force a termination for each
         entry.activity[20]  = '\0';
@@ -1236,8 +1239,11 @@ void alert_build_list(Message *fill) {
                 entry.alert_tag,
                 compressed_wx);     // Stick the long string in here
 
-            if (ret != 3)
+            if (ret != 3) {
                 fprintf(stderr,"sscanf parsed %d/3 values in alert.c\n", ret);
+                compressed_wx[0] = '\0';  // Remove stale compressed alerts.
+                compressed_wx_packet = 0; //Clear flag in error condition.
+            }
 
             compressed_wx[255] = '\0';
 
