@@ -1,9 +1,9 @@
 /*
- * $Id: database.h,v 1.37 2006/09/19 15:58:56 chicoreus Exp $
+ * $Id: database.h,v 1.42 2007/04/27 13:44:00 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -563,7 +563,7 @@ extern void update_messages(int force);
 extern void mdelete_messages_from(char *from);
 extern void mdelete_messages_to(char *to);
 extern void init_message_data(void);
-extern void check_message_remove(int curr_sec);
+extern void check_message_remove(time_t curr_sec);
 extern int  new_message_data;
 extern time_t msg_data_add(char *call_sign, char *from_call, char *data,
                            char *seq, char type, char from, long *record_out);
@@ -589,7 +589,7 @@ extern int  next_station_time(DataRow **p_curr);
 extern int  prev_station_time(DataRow **p_curr);
 extern int  search_station_name(DataRow **p_name, char *call, int exact);
 extern int  search_station_time(DataRow **p_time, time_t heard, int serial);
-extern void check_station_remove(int curr_sec);
+extern void check_station_remove(time_t curr_sec);
 extern void delete_all_stations(void);
 extern void station_del(char *callsign);
 extern void my_station_add(char *my_call_sign, char my_group, char my_symbol,
@@ -640,4 +640,7 @@ void Show_Aloha_Stats(Widget w, XtPointer clientData,
                       XtPointer callData); // popup window
 
 int comp_by_dist(const void *,const void *);// used only for qsort
+DataRow * sanity_check_time_list(time_t); // used only for debugging
+void dump_time_sorted_list(void);
+
 #endif /* XASTIR_DATABASE_H */
