@@ -1,15 +1,19 @@
 
-// $Id: geo-find.c,v 1.10 2005/08/30 20:28:50 kd6zwr Exp $
+// $Id: geo-find.c,v 1.13 2007/01/03 19:39:08 we7u Exp $
 
 
 /* Copyright 2002 Daniel Egnor.  See LICENSE.geocoder file.
- * Portions Copyright (C) 2004-2005  The Xastir Group
+ * Portions Copyright (C) 2004-2007  The Xastir Group
  *
  * The geo_find() function defined here uses an address map built by 
  * geo-*-to-* to parse an address and convert it to geographical
  * coordinates.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "geo.h"
 #include "io.h"
 
