@@ -1,9 +1,9 @@
 /*
- * $Id: igate.h,v 1.5 2004/01/26 16:18:21 we7u Exp $
+ * $Id: igate.h,v 1.9 2007/01/03 19:39:08 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2004  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +33,7 @@ typedef struct {
 extern void igate_init(void);
 extern void insert_into_heard_queue(int port, char *line);
 extern void output_igate_net(char *line, int port, int third_party);
-extern void output_igate_rf(char *from, char *call, char *path, char *line, int port, int third_party);
+extern void output_igate_rf(char *from, char *call, char *path, char *line, int port, int third_party, char *object_name);
 extern void output_nws_igate_rf(char *from, char *path, char *line, int port, int third_party);
 
 #endif  // __XASTIR_IGATE_H
