@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_WMS.c,v 1.23 2006/08/07 19:51:05 we7u Exp $
+ * $Id: map_WMS.c,v 1.26 2007/03/06 19:31:13 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -77,7 +77,7 @@
 
 #define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
 
-#ifdef HAVE_IMAGEMAGICK
+#ifdef HAVE_MAGICK
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
@@ -100,7 +100,12 @@
 #undef PACKAGE_TARNAME
 #define XASTIR_PACKAGE_VERSION PACKAGE_VERSION
 #undef PACKAGE_VERSION
+#ifdef HAVE_GRAPHICSMAGICK
+/*#include <GraphicsMagick/magick/api.h>*/
 #include <magick/api.h>
+#else   // HAVE_GRAPHICSMAGICK
+#include <magick/api.h>
+#endif  // HAVE_GRAPHICSMAGICK 
 #undef PACKAGE_BUGREPORT
 #define PACKAGE_BUGREPORT XASTIR_PACKAGE_BUGREPORT
 #undef XASTIR_PACKAGE_BUGREPORT
@@ -116,7 +121,7 @@
 #undef PACKAGE_VERSION
 #define PACKAGE_VERSION XASTIR_PACKAGE_VERSION
 #undef XASTIR_PACKAGE_VERSION
-#endif // HAVE_IMAGEMAGICK
+#endif // HAVE_MAGICK
 
 // Must be last include file
 #include "leak_detection.h"
@@ -133,7 +138,7 @@ extern int mag;
 /**********************************************************
  * draw_WMS_map()
  **********************************************************/
-#ifdef HAVE_IMAGEMAGICK
+#ifdef HAVE_MAGICK
 void draw_WMS_map (Widget w,
         char *filenm,
         int destination_pixmap,
@@ -1000,4 +1005,4 @@ void draw_WMS_map (Widget w,
     if (image_info)
        DestroyImageInfo(image_info);
 }
-#endif //HAVE_IMAGEMAGICK
+#endif //HAVE_MAGICK
