@@ -1,9 +1,9 @@
 /*
- * $Id: map_cache.c,v 1.24 2006/04/24 19:21:41 we7u Exp $
+ * $Id: map_cache.c,v 1.26 2007/02/10 03:04:41 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -240,8 +240,9 @@ int map_cache_put( char * map_cache_url, char * map_cache_file ){
     mc_key.size = sizeof("CACHE_SPACE_USED"); 
 
 // check "CACHE_SPACE_USED" record in db
-	
-    if (((mc_ret = dbp->get(dbp, NULL, &mc_key, &mc_data, 0)) == 0) &&  ( mc_data.data != NULL ) ) {
+
+// mc_ret is assigned here but not used.  Commented it out for now.
+    if (((/* mc_ret = */ dbp->get(dbp, NULL, &mc_key, &mc_data, 0)) == 0) &&  ( mc_data.data != NULL ) ) {
         ( debug_level & 512 ) && fprintf(stderr, "map_cache_put: %s: key retrieved: data was %s.\n",
             (mc_key.data == NULL) ? "(null)" : (char *)mc_key.data,
             (mc_data.data == NULL) ? "(null)" : (char *)mc_data.data);
