@@ -1,9 +1,9 @@
 /*
- * $Id: messages_gui.c,v 1.71 2006/09/09 00:35:50 we7u Exp $
+ * $Id: messages_gui.c,v 1.77 2007/01/14 03:57:45 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,6 +42,10 @@
 #include "leak_detection.h"
 
 
+#if defined(__LSB__) || defined(LESSTIF_VERSION)
+  #define NO_DYNAMIC_WIDGETS 1
+#endif
+
 
 #define MAX_PATH 200
 
@@ -54,7 +58,8 @@ static xastir_mutex auto_msg_dialog_lock;
 xastir_mutex send_message_dialog_lock;
 
 void select_station_type(int ii);
- 
+
+
 
 
 
@@ -823,6 +828,8 @@ void Send_message_destroy_shell( /*@unused@*/ Widget widget, XtPointer clientDat
     int ii;
 //    char *temp_ptr;
 //    char temp1[MAX_LINE_SIZE+1];
+
+//fprintf(stderr,"3Send_message_destroy_shell() start\n");
  
     ii=atoi((char *)clientData);
 
@@ -857,6 +864,7 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_d
         XtDestroyWidget(mw[ii].send_message_dialog);
     }
 
+
     mw[ii].send_message_dialog = (Widget)NULL;
     mw[ii].to_call_sign[0] = '\0';
     mw[ii].send_message_call_data = (Widget)NULL;
@@ -873,6 +881,8 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_d
  
 end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_destroy_shell" );
 
+//fprintf(stderr,"3Send_message_destroy_shell() finished\n");
+ 
 }
 
 
@@ -930,9 +940,13 @@ void Send_message_now( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/
     char temp1[MAX_CALLSIGN+1];
     char temp2[68];
     char temp_line1[68] = "";
+
+#ifndef NO_DYNAMIC_WIDGETS
     char temp_line2[23] = "";
     char temp_line3[23] = "";
     char temp_line4[10] = "";
+#endif	// NO_DYNAMIC_WIDGETS
+
     char path[200];
     int ii, jj;
     char *temp_ptr;
@@ -971,6 +985,8 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_n
             temp_ptr);
         XtFree(temp_ptr);
 
+#ifndef NO_DYNAMIC_WIDGETS
+
         // If D700/D7 mode, fetch message_data_line2
         if (d700 || d7) {
             temp_ptr = XmTextFieldGetString(mw[ii].message_data_line2);
@@ -1026,7 +1042,11 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_n
                 temp_line3,
                 temp_line4);
         }
-        else {  // Use line1 only
+        else
+
+#endif  // NO_DYNAMIC_WIDGETS 
+
+        {  // Use line1 only
             xastir_snprintf(temp2,
                 sizeof(temp2),
                 "%s",
@@ -1300,7 +1320,7 @@ void Clear_messages_to( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*
 void Send_message_call( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
     char call[20];
 
-    if(clientData !=NULL) {
+    if(clientData != NULL) {
         xastir_snprintf(call,
             sizeof(call),
             "%s",
@@ -1313,13 +1333,41 @@ void Send_message_call( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*
 
 
 
+// These are used for callbacks below so that we have a unique
+// identifier for the XtRemoveCallback() function to work with.  The
+// last two parameters of an XtAddCallback() or XtRemoveCallback()
+// must be unique.
+//
+void Send_message_now_1( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    Send_message_now( w, clientData, callData);
+}
+void Send_message_now_2( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    Send_message_now( w, clientData, callData);
+}
+void Send_message_now_3( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    Send_message_now( w, clientData, callData);
+}
+void Send_message_now_4( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    Send_message_now( w, clientData, callData);
+}
+
+
+
+
+
 void build_send_message_input_boxes(int i, int hamhud, int d700, int d7) {
 
-//fprintf(stderr, "  build:   i:%d  hamhud:%d  d700:%d  d7:%d\n", i, hamhud, d700, d7);
+//fprintf(stderr, "\n  build:   i:%d  hamhud:%d  d700:%d  d7:%d\n", i, hamhud, d700, d7);
+
+
+// Skip most of these sections and go to the default section if
+// using LSB.  We have problems with Lesstif segfaulting on us
+// otherwise.
+
+#ifndef NO_DYNAMIC_WIDGETS
 
     // HamHUD mode (Here we're assuming the 4x20 LCD in the HamHUD-II)
     if (hamhud) {
-
         // Draw a textfield widget of size 20
         mw[i].message_data_line1 = XtVaCreateManagedWidget("Send_message smmd", 
             xmTextFieldWidgetClass, 
@@ -1555,7 +1603,12 @@ void build_send_message_input_boxes(int i, int hamhud, int d700, int d7) {
    }
 
     // Standard APRS Mode
-   else {  // Standard APRS message box size (67)
+   else // Standard APRS message box size (67)
+
+#endif  // NO_DYNAMIC_WIDGETS
+
+    {
+
        mw[i].message_data_line1 = XtVaCreateManagedWidget("Send_message smmd", 
             xmTextFieldWidgetClass, 
             mw[i].form,
@@ -1580,17 +1633,24 @@ void build_send_message_input_boxes(int i, int hamhud, int d700, int d7) {
             NULL);
     }
 
+
+//fprintf(stderr,"Starting to add callbacks\n");
+
+
     if (mw[i].message_data_line1) // If exists, add another callback
-        XtAddCallback(mw[i].message_data_line1, XmNactivateCallback, Send_message_now, (XtPointer)mw[i].win);
+        XtAddCallback(mw[i].message_data_line1, XmNactivateCallback, Send_message_now_1, (XtPointer)mw[i].win);
 
     if (mw[i].message_data_line2) // If exists, add another callback
-        XtAddCallback(mw[i].message_data_line2, XmNactivateCallback, Send_message_now, (XtPointer)mw[i].win);
+        XtAddCallback(mw[i].message_data_line2, XmNactivateCallback, Send_message_now_2, (XtPointer)mw[i].win);
 
     if (mw[i].message_data_line3) // If exists, add another callback
-        XtAddCallback(mw[i].message_data_line3, XmNactivateCallback, Send_message_now, (XtPointer)mw[i].win);
+        XtAddCallback(mw[i].message_data_line3, XmNactivateCallback, Send_message_now_3, (XtPointer)mw[i].win);
 
     if (mw[i].message_data_line4) // If exists, add another callback
-        XtAddCallback(mw[i].message_data_line4, XmNactivateCallback, Send_message_now, (XtPointer)mw[i].win);
+        XtAddCallback(mw[i].message_data_line4, XmNactivateCallback, Send_message_now_4, (XtPointer)mw[i].win);
+
+//fprintf(stderr,"Exiting build_send_message_input_boxes()\n");
+
 }
 
 
@@ -1602,50 +1662,46 @@ void rebuild_send_message_input_boxes(int ii, int hamhud, int d700, int d7) {
 //fprintf(stderr, "\nrebuild:  ii:%d  hamhud:%d  d700:%d  d7:%d\n", ii, hamhud, d700, d7);
 
 
-    // Take down the dialog
-//    XtPopdown(mw[ii].send_message_dialog);
-
-
-    // Remove callbacks 
-    if (mw[ii].message_data_line1) // If exists, remove callback callback
-        XtRemoveCallback(mw[ii].message_data_line1, XmNactivateCallback, Send_message_now, (XtPointer)mw[ii].win);
-
-    if (mw[ii].message_data_line2) // If exists, remove callback
-        XtRemoveCallback(mw[ii].message_data_line2, XmNactivateCallback, Send_message_now, (XtPointer)mw[ii].win);
-
-    if (mw[ii].message_data_line3) // If exists, remove callback
-        XtRemoveCallback(mw[ii].message_data_line3, XmNactivateCallback, Send_message_now, (XtPointer)mw[ii].win);
-
-    if (mw[ii].message_data_line4) // If exists, remove callback
-        XtRemoveCallback(mw[ii].message_data_line4, XmNactivateCallback, Send_message_now, (XtPointer)mw[ii].win);
+// Lesstif appears to have a problem with removing/adding widgets to
+// a dialog that's already been created and will segfault in this
+// case.  In order to make LSB-Xastir more reliable we disable the
+// dynamically-created widget code here and stick with the default
+// setup (one long TextField widget for input).
+//
+// Perhaps we need to do a Lesstif detect and do the same thing
+// anytime Lesstif is used as well?
 
+#ifndef NO_DYNAMIC_WIDGETS
 
     // Remove the current message widgets
-    if (mw[ii].message_data_line4)
+    if (mw[ii].message_data_line4) {
         XtDestroyWidget(mw[ii].message_data_line4);
+    }
 
-    if (mw[ii].message_data_line3)
+    if (mw[ii].message_data_line3) {
         XtDestroyWidget(mw[ii].message_data_line3);
+    }
 
-    if (mw[ii].message_data_line2)
+    if (mw[ii].message_data_line2) {
         XtDestroyWidget(mw[ii].message_data_line2);
+    }
 
-    if (mw[ii].message_data_line1)
+    if (mw[ii].message_data_line1) {
         XtDestroyWidget(mw[ii].message_data_line1);
+    }
 
 
-    mw[ii].message_data_line1 = NULL;
-    mw[ii].message_data_line2 = NULL;
-    mw[ii].message_data_line3 = NULL;
-    mw[ii].message_data_line4 = NULL;
+    mw[ii].message_data_line1 = (Widget)NULL;
+    mw[ii].message_data_line2 = (Widget)NULL;
+    mw[ii].message_data_line3 = (Widget)NULL;
+    mw[ii].message_data_line4 = (Widget)NULL;
 
 
     // Build the new boxes
     build_send_message_input_boxes(ii, hamhud, d700, d7);
 
+#endif  // NO_DYNAMIC_WIDGETS
 
-    // Bring up the reconstructed dialog
-//    XtPopup(mw[ii].send_message_dialog, XtGrabNone);
 }
 
 
@@ -1718,6 +1774,11 @@ void select_station_type(int ii) {
     char *temp_ptr;
 
 
+    if (mw[ii].send_message_call_data == NULL) {
+        fprintf(stderr,"messages_gui.c:select_station_type():mw[ii].send_message_call_data is NULL\n");
+        return;
+    }
+
     temp_ptr = XmTextFieldGetString(mw[ii].send_message_call_data);
     xastir_snprintf(call_sign,
         sizeof(call_sign),
@@ -1762,16 +1823,19 @@ void select_station_type(int ii) {
         }
 
         // If not D700 or D7, check for HamHUD in the TOCALL.
-        // APHH2/APRHH2.  We'll skip the version number soas to
+        // APHH2/APRHH2.  We'll skip the version number so-as to
         // catch future versions as well.
         //
         if (!d700 && !d7) {
-            if (strncmp(p_station->node_path_ptr,"APRHH",5) == 0
-                    || strncmp(p_station->node_path_ptr,"APHH",4) == 0) {
-                hamhud++;
+            if (p_station->node_path_ptr) {
+                if (strncmp(p_station->node_path_ptr,"APRHH",5) == 0
+                        || strncmp(p_station->node_path_ptr,"APHH",4) == 0) {
+                    hamhud++;
+                }
             }
         }
 
+
         if (hamhud) {
 //            fprintf(stderr,"HamHUD found\n");
             XmToggleButtonSetState(mw[ii].HamHUD_mode,TRUE,FALSE);
@@ -1843,10 +1907,9 @@ void Send_message( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtP
     int groupon;
     int box_len;
     Atom delw;
-//    DataRow *p_station;
 
 
-//fprintf(stderr,"Send_message\n");
+//fprintf(stderr,"\n1Send_message\n");
 
     groupon=0;
     box_len=105;
@@ -2032,7 +2095,11 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
                 NULL);
+#ifndef NO_DYNAMIC_WIDGETS
         XtAddCallback(mw[i].D7_mode,XmNvalueChangedCallback,D7_Msg,(XtPointer)i);
+#else   // NO_DYNAMIC_WIDGETS
+        XtSetSensitive(mw[i].D7_mode, FALSE);
+#endif  // NO_DYNAMIC_WIDGETS
 
         mw[i].D700_mode =XtVaCreateManagedWidget("D700",
                 xmToggleButtonGadgetClass,
@@ -2051,7 +2118,12 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
             NULL);
+
+#ifndef NO_DYNAMIC_WIDGETS
         XtAddCallback(mw[i].D700_mode,XmNvalueChangedCallback,D700_Msg,(XtPointer)i);
+#else   // NO_DYNAMIC_WIDGETS
+        XtSetSensitive(mw[i].D700_mode, FALSE);
+#endif  // NO_DYNAMIC_WIDGETS
 
         mw[i].HamHUD_mode =XtVaCreateManagedWidget("HamHUD",
                 xmToggleButtonGadgetClass,
@@ -2070,7 +2142,12 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 MY_FOREGROUND_COLOR,
                 MY_BACKGROUND_COLOR,
             NULL);
+
+#ifndef NO_DYNAMIC_WIDGETS
         XtAddCallback(mw[i].HamHUD_mode,XmNvalueChangedCallback,HamHUD_Msg,(XtPointer)i);
+#else   // NO_DYNAMIC_WIDGETS
+        XtSetSensitive(mw[i].HamHUD_mode, FALSE);
+#endif  // NO_DYNAMIC_WIDGETS
 
         mw[i].message = XtVaCreateManagedWidget(langcode("WPUPMSB008"),
                 xmLabelWidgetClass, 
@@ -2248,7 +2325,7 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
  
         XtAddCallback(mw[i].button_ok, XmNactivateCallback, Send_message_now, (XtPointer)mw[i].win);
 
-        XtAddCallback(mw[i].button_cancel, XmNactivateCallback, Send_message_destroy_shell,(XtPointer)mw[i].win);
+        XtAddCallback(mw[i].button_cancel, XmNactivateCallback, Send_message_destroy_shell, (XtPointer)mw[i].win);
  
 // Note group messages isn't implemented fully yet.  When it is, the following might have
 // to change again:
@@ -2290,10 +2367,15 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
 
     }
 
+//fprintf(stderr,"2calling select_station_type()\n");
+
     // Re-arrange the outgoing message boxes based on the type of
     // device we're talking to.
     select_station_type(i);
  
+//fprintf(stderr,"2returned from select_station_type()\n");
+//fprintf(stderr,"1end of Send_message()\n");
+
 end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message" );
 
 }
@@ -2302,6 +2384,34 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message" );
 
 
 
+// Bring up a Send Message dialog for each QSO that has pending
+// outbound messages.
+//
+void Show_pending_messages( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
+    int ii;
+
+
+    // Look through the outgoing message queue.  Find all callsigns
+    // that we're currently trying to send messages to.
+    //
+    for (ii = 0; ii < MAX_OUTGOING_MESSAGES; ii++) {
+
+        // If it matches the callsign we're talking to
+        if (message_pool[ii].active==MESSAGE_ACTIVE) {
+
+            // Bring up a Send Message box for each callsign found.
+            Send_message_call(NULL, message_pool[ii].to_call_sign, NULL);
+
+            // Fill in the old data in case it doesn't auto-fill
+            Check_new_call_messages(NULL, (XtPointer)ii, NULL);
+        }
+    }
+}
+
+
+
+
+
 /************************* Auto msg **************************************/
 /*************************************************************************/
 void Auto_msg_option( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer calldata) {
