@@ -1,9 +1,9 @@
 /*
- * $Id: util.h,v 1.48 2006/08/31 21:36:06 we7u Exp $
+ * $Id: util.h,v 1.51 2007/01/03 19:39:13 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -115,6 +115,7 @@ extern void compute_current_DR_position(DataRow *p_station, long *x_long, long *
 
 extern int  filethere(char *fn);
 extern int  filecreate(char *fn);
+extern int copy_file(char *infilename, char *outfilename);
 extern time_t file_time(char *fn);
 extern void load_wx_alerts_from_log(void);
 extern void log_data(char *file, char *line);
@@ -167,6 +168,7 @@ extern int check_unproto_path( char *data );
 extern void set_dangerous( char *ptr );
 extern void clear_dangerous(void);
 
+void xastirWriteWKT(char *name);
 
 #endif // __XASTIR_UTIL_H
 
