@@ -1,9 +1,9 @@
 /*
- * $Id: wx_gui.c,v 1.47 2006/08/31 21:27:08 we7u Exp $
+ * $Id: wx_gui.c,v 1.52 2007/02/24 22:08:54 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,11 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
+#include <sys/socket.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #ifdef  HAVE_LOCALE_H
 #include <locale.h>
@@ -116,8 +121,11 @@ void wx_alert_finger_output( Widget widget, char *handle) {
     register unsigned int ac = 0;   // Arg Count
     char temp[1024];
     XmString item;
-    register FILE *pp;
-    extern FILE *popen(const char *, const char *);
+    FILE *fd;
+    int ret;
+    int server_fd;
+    struct sockaddr_in serv_addr;
+    struct hostent *serverhost;
 
 
     if (debug_level & 1)
@@ -229,36 +237,135 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_alert_double_cl
     // case it was left up from a previous query.
     XmListDeleteAllItems(wx_detailed_alert_list);
 
-    // Perform a "finger" command in another process
+    // Perform a "finger" command, which is really just a telnet
+    // with a single line command sent to the remote host, then a
+    // bunch of text sent back.  We implement it here via our own
+    // TCP code, as it's really very simple.
+
+    // Allocate a socket for our use
+    if ((server_fd = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0) {
+//        fprintf(stderr,"wx_alert_finger_output: can't get socket\n");
+        xastir_snprintf(temp,
+            sizeof(temp),
+            "wx_alert_finger_output: can't get socket");
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+        return;
+    }
+
+    memset(&serv_addr, 0, sizeof(serv_addr));
+
+    serverhost = gethostbyname("wxsvr.net");
+    if (serverhost == (struct hostent *)0) {
+//        fprintf(stderr,"wx_alert_finger_output: gethostbyname failed\n");
+        xastir_snprintf(temp,
+            sizeof(temp),
+            "wx_alert_finger_output: gethostbyname failed");
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+        (void)close(server_fd); // Close the socket
+        return;
+    }
+    memmove(&serv_addr.sin_addr,serverhost->h_addr, (size_t)serverhost->h_length);
+    serv_addr.sin_family = AF_INET;
+    serv_addr.sin_port = htons(79); // Finger protocol uses port 79
+
+    if (connect(server_fd, (struct sockaddr *)&serv_addr, sizeof(serv_addr)) != 0) {
+//        fprintf(stderr,"wx_alert_finger_output: connect to server failed\n");
+        xastir_snprintf(temp,
+            sizeof(temp),
+            "wx_alert_finger_output: connect to server failed");
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+        (void)close(server_fd);    // Close the socket
+        return;
+    }
+
+    // Create a file descriptor for the socket
+    fd = fdopen(dup(server_fd),"wb");
+    if (fd == NULL) {
+//        fprintf(stderr,"Couldn't create duplicate write socket\n");
+        xastir_snprintf(temp,
+            sizeof(temp),
+            "Couldn't create duplicate write socket");
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+        (void)close(server_fd); // Close the socket
+        return;
+    }
+
+    // Set up the text we're going to send to the remote finger
+    // server.
     xastir_snprintf(temp,
         sizeof(temp),
-        "/usr/bin/finger %s@wxsvr.net",
+        "%s\r\n",
         handle);
-    if (!(pp = popen (temp, "r"))) {    // Go do the finger command
-        perror (temp);  // Print an error message if it failed
-        fprintf(stderr,"Weather server didn't answer or 'finger' command couldn't be run\n");
+
+    // Send the request text out the socket
+    ret = fprintf(fd, temp);
+
+    if (ret == 0 || ret == -1) {
+//        fprintf(stderr,"Couldn't send finger command to wxsvr\n");
+        xastir_snprintf(temp,
+            sizeof(temp),
+            "Couldn't send finger command to wxsvr");
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+        (void)fclose(fd);
+        (void)close(server_fd); // Close the socket
+        return;
     }
-    else {
-        while (fgets (temp, sizeof (temp), pp)) {   // While we have data to process
-            char *ptr;
 
-            // Remove any linefeeds or carriage returns from each
-            // string.
-            ptr = temp;
-            while ( (ptr = strpbrk(temp, "\n\r")) )
-                memmove(ptr, ptr+1, strlen(ptr)+1);
+    // Close the duplicate port we used for writing
+    (void)fclose(fd);
 
-            if (debug_level & 1)
-                fprintf(stderr,"%s\n",temp);
+//
+// Read back the results from the socket
+//
 
-            // Create an XmString for each line and add it to the
-            // end of the list.
-            item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
-            XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
-            XmStringFree(item);
-        }
-        pclose (pp);
+    // Create a file descriptor for the socket
+    fd = fdopen(dup(server_fd),"rb");
+    if (fd == NULL) {
+//        fprintf(stderr,"Couldn't create duplicate read socket\n");
+        xastir_snprintf(temp,
+            sizeof(temp),
+            "Couldn't create duplicate read socket");
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+        (void)close(server_fd); // Close the socket
+        return;
     }
+
+    // Process the data we received from the remote finger server
+    //
+    while (fgets (temp, sizeof (temp), fd)) {   // While we have data to process
+        char *ptr;
+
+        // Remove any linefeeds or carriage returns from each
+        // string.
+        ptr = temp;
+        while ( (ptr = strpbrk(temp, "\n\r")) )
+            memmove(ptr, ptr+1, strlen(ptr)+1);
+
+        if (debug_level & 1)
+            fprintf(stderr,"%s\n",temp);
+
+        // Create an XmString for each line and add it to the
+        // end of the list.
+        item = XmStringCreateLtoR(temp, XmFONTLIST_DEFAULT_TAG);
+        XmListAddItemUnselected(wx_detailed_alert_list, item, 0);
+        XmStringFree(item);
+    }
+
+    // All done!
+    fclose(fd);
+    (void)close(server_fd); // Close the socket
 }
 
 
@@ -283,6 +390,8 @@ void wx_alert_double_click_action( Widget widget, XtPointer clientData, XtPointe
         "%s",
         choice);
 
+    XtFree(choice);	// Release as soon as we're done!
+
     handle[13] = '\0';  // Terminate the string
     // Remove spaces
     ptr = handle;
@@ -294,8 +403,6 @@ void wx_alert_double_click_action( Widget widget, XtPointer clientData, XtPointe
         fprintf(stderr,"Handle: %s\n",handle);
 
     wx_alert_finger_output( widget, handle);
-
-    XtFree(choice);
 }
 
 
@@ -448,7 +555,7 @@ begin_critical_section(&wx_alert_shell_lock, "wx_gui.c:wx_alert_update_list" );
                 XmListAddItemUnselected(wx_alert_list, item, 0);
             } else {
 		// Replace it in the window.  Note: This might re-order the list each time.
-                XmListReplaceItemsPosUnselected(wx_alert_list, &item, 1, ii);
+                XmListReplaceItemsPos(wx_alert_list, &item, 1, ii);
             }
 
             XmStringFree(item);
