@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xa_config.c,v 1.161 2006/09/19 14:43:46 chicoreus Exp $
+ * $Id: xa_config.c,v 1.169 2007/01/08 21:47:13 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -214,9 +214,9 @@ int get_int(char *option, int low, int high, int def) {
     }
 
     if (!ret) {
-        fprintf(stderr,"xastir.cnf: %s not found, inserting default: %d\n",
-            option,
-            def);
+//        fprintf(stderr,"xastir.cnf: %s not found, inserting default: %d\n",
+//            option,
+//            def);
         return(def);
     }
 
@@ -243,9 +243,9 @@ long get_long(char *option, long low, long high, long def) {
     }
 
     if (!ret) {
-        fprintf(stderr,"xastir.cnf: %s not found, inserting default: %ld\n",
-            option,
-            def);
+//        fprintf(stderr,"xastir.cnf: %s not found, inserting default: %ld\n",
+//            option,
+//            def);
         return(def);
     }
 
@@ -319,7 +319,12 @@ char *get_data_base_dir(char *dir) {
     char *env_ptr;
 
     // Snag this variable from the environment if it exists there,
-    // else grab it from the define in config.h
+    // else grab it from the define from the compile command-line
+    // that should look like one of these:
+    //
+    // -DXASTIR_DATA_BASE=\"/opt/Xastir/share/xastir\"
+    // -DXASTIR_DATA_BASE=\"/usr/local/share/xastir\"
+    //
     xastir_snprintf(base,
         sizeof(base),
         "%s",
@@ -532,14 +537,17 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         store_int (fout, "MAP_DRAW_FILLED_COLORS", map_color_fill);
 
 #if !defined(NO_GRAPHICS)
-#if defined(HAVE_IMAGEMAGICK)
+#if defined(HAVE_MAGICK)
         sprintf (name, "%f", imagemagick_gamma_adjust);
         store_string(fout, "IMAGEMAGICK_GAMMA_ADJUST", name);
-#endif  // HAVE_IMAGEMAGICK
+#endif  // HAVE_MAGICK
         sprintf (name, "%f", raster_map_intensity);
         store_string(fout, "RASTER_MAP_INTENSITY", name);
 #endif  // NO_GRAPHICS
 
+        store_string(fout, "PRINT_PROGRAM", printer_program);
+        store_string(fout, "PREVIEWER_PROGRAM", previewer_program);
+
         store_int (fout, "MAP_LETTERSTYLE", letter_style);
         store_int (fout, "MAP_ICONOUTLINESTYLE", icon_outline_style);
         store_int (fout, "MAP_WX_ALERT_STYLE", wx_alert_style);
@@ -575,7 +583,7 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         store_string (fout, "MAPS_LABEL_FONT_BORDER", rotated_label_fontname[FONT_BORDER]);
         store_string (fout, "MAPS_LABEL_FONT", rotated_label_fontname[FONT_DEFAULT]);
 //N0VH
-#if defined(HAVE_IMAGEMAGICK)
+#if defined(HAVE_MAGICK)
         store_int (fout, "NET_MAP_TIMEOUT", net_map_timeout);
         store_int (fout, "TIGERMAP_SHOW_GRID", tiger_show_grid);
         store_int (fout, "TIGERMAP_SHOW_COUNTIES", tiger_show_counties);
@@ -591,7 +599,7 @@ fprintf(stderr,"X:%d  y:%d\n", (int)x_return, (int)y_return);
         store_int (fout, "TIGERMAP_SHOW_WATER", tiger_show_water);
         store_int (fout, "TIGERMAP_SHOW_LAKES", tiger_show_lakes);
         store_int (fout, "TIGERMAP_SHOW_MISC", tiger_show_misc);
-#endif //HAVE_IMAGEMAGICK
+#endif //HAVE_MAGICK
 
 #ifdef HAVE_LIBGEOTIFF
         store_int (fout, "DRG_XOR_COLORS", DRG_XOR_colors);
@@ -1141,9 +1149,8 @@ void load_data_or_default(void) {
     my_trail_diff_color = get_int ("MY_TRAIL_DIFF_COLOR", 0, 1, 0);
 
     /* default values */
-    screen_width = get_long ("SCREEN_WIDTH", 61l, 10000l, 61l);
-    screen_height = get_long ("SCREEN_HEIGHT", 1l, 10000l, 1l);
-
+    screen_width = get_long ("SCREEN_WIDTH", 61l, 10000l, 590l);
+    screen_height = get_long ("SCREEN_HEIGHT", 1l, 10000l, 420l);
 
 //    screen_x_offset = (Position)get_int ("SCREEN_X_OFFSET", 0, 10000, 0);
 //    screen_y_offset = (Position)get_int ("SCREEN_Y_OFFSET", 0, 10000, 0);
@@ -1171,7 +1178,7 @@ void load_data_or_default(void) {
     map_color_fill = get_int ( "MAP_DRAW_FILLED_COLORS", 0, 1, 1);
 
 #if !defined(NO_GRAPHICS)
-#if defined(HAVE_IMAGEMAGICK)
+#if defined(HAVE_MAGICK)
     if (!get_string("IMAGEMAGICK_GAMMA_ADJUST", name, sizeof(name))
             || name[0] == '\0') {
         imagemagick_gamma_adjust = 0.0;
@@ -1181,7 +1188,7 @@ void load_data_or_default(void) {
             fprintf(stderr,"load_data_or_default:sscanf parsing error\n");
         }
     }
-#endif  // HAVE_IMAGEMAGICK
+#endif  // HAVE_MAGICK
     if (!get_string("RASTER_MAP_INTENSITY", name, sizeof(name))
             || name[0] == '\0') {
         raster_map_intensity = 1.0;
@@ -1193,11 +1200,38 @@ void load_data_or_default(void) {
     }
 #endif  // NO_GRAPHICS
 
+    if (!get_string ("PRINT_PROGRAM", printer_program, sizeof(printer_program))
+            || printer_program[0] == '\0') {
+        xastir_snprintf(printer_program,
+            sizeof(printer_program),
+            "%s",
+#ifdef LPR_PATH
+            // Path to LPR if defined
+            LPR_PATH);
+#else // LPR_PATH
+            // Empty path
+            "");
+#endif // LPR_PATH
+    }
+    if (!get_string ("PREVIEWER_PROGRAM", previewer_program, sizeof(previewer_program))
+            || previewer_program[0] == '\0') {
+        xastir_snprintf(previewer_program,
+            sizeof(previewer_program),
+            "%s",
+#ifdef GV_PATH
+            // Path to GV if defined
+            GV_PATH);
+#else // GV_PATH
+            // Empty path
+            "");
+#endif // GV_PATH
+    }
+
     letter_style = get_int ("MAP_LETTERSTYLE", 0, 2, 1);
 
     icon_outline_style = get_int ("MAP_ICONOUTLINESTYLE", 0, 3, 0);
 
-    wx_alert_style = get_int ("MAP_WX_ALERT_STYLE", 0, 1, 1);
+    wx_alert_style = get_int ("MAP_WX_ALERT_STYLE", 0, 1, 0);
 
     // Empty string is ok here
     if (!get_string("ALTNET_CALL", altnet_call, sizeof(altnet_call)))
@@ -1317,7 +1351,7 @@ void load_data_or_default(void) {
 
     draw_labeled_grid_border = get_int ("MAPS_LABELED_GRID_BORDER", 0, 1, 0);
 
-    map_color_levels = get_int ("MAPS_LEVELS", 0, 1, 0);
+    map_color_levels = get_int ("MAPS_LEVELS", 0, 1, 1);
 
     map_labels = get_int ("MAPS_LABELS", 0, 1, 1);
 
@@ -1377,7 +1411,7 @@ void load_data_or_default(void) {
     }
 
 //N0VH
-#if defined(HAVE_IMAGEMAGICK)
+#if defined(HAVE_MAGICK)
     net_map_timeout = get_int ("NET_MAP_TIMEOUT", 10, 300, 120);
 
     tiger_show_grid = get_int ("TIGERMAP_SHOW_GRID", 0, 1, 0);
@@ -1394,7 +1428,7 @@ void load_data_or_default(void) {
     tiger_show_water = get_int ("TIGERMAP_SHOW_WATER", 0, 1, 1);
     tiger_show_lakes = get_int ("TIGERMAP_SHOW_LAKES", 0, 1, 1);
     tiger_show_misc = get_int ("TIGERMAP_SHOW_MISC", 0, 1, 1);
-#endif //HAVE_IMAGEMAGICK
+#endif //HAVE_MAGICK
 
 #ifdef HAVE_LIBGEOTIFF
     DRG_XOR_colors = get_int ("DRG_XOR_COLORS", 0, 1, 0);
@@ -1442,17 +1476,17 @@ void load_data_or_default(void) {
     Display_.phg_of_moving = get_int ("DISPLAY_MOBILES_PHG", 0, 1, 0);
     Display_.altitude = get_int ("DISPLAY_ALTITUDE", 0, 1, 0);
     Display_.course = get_int ("DISPLAY_COURSE", 0, 1, 0);
-    Display_.speed = get_int ("DISPLAY_SPEED", 0, 1, 0);
+    Display_.speed = get_int ("DISPLAY_SPEED", 0, 1, 1);
     Display_.speed_short = get_int ("DISPLAY_SPEED_SHORT", 0, 1, 0);
     Display_.dist_bearing = get_int ("DISPLAY_DIST_COURSE", 0, 1, 0);
-    Display_.weather = get_int ("DISPLAY_WEATHER", 0, 1, 0);
-    Display_.weather_text = get_int ("DISPLAY_STATION_WX", 0, 1, 0);
+    Display_.weather = get_int ("DISPLAY_WEATHER", 0, 1, 1);
+    Display_.weather_text = get_int ("DISPLAY_STATION_WX", 0, 1, 1);
     Display_.temperature_only = get_int ("DISPLAY_TEMP_ONLY", 0, 1, 0);
-    Display_.wind_barb = get_int ("DISPLAY_WIND_BARB", 0, 1, 0);
+    Display_.wind_barb = get_int ("DISPLAY_WIND_BARB", 0, 1, 1);
     Display_.trail = get_int ("DISPLAY_STATION_TRAILS", 0, 1, 1);
     Display_.last_heard = get_int ("DISPLAY_LAST_HEARD", 0, 1, 0);
-    Display_.ambiguity = get_int ("DISPLAY_POSITION_AMB", 0, 1, 0);
-    Display_.df_data = get_int ("DISPLAY_DF_INFO", 0, 1, 0);
+    Display_.ambiguity = get_int ("DISPLAY_POSITION_AMB", 0, 1, 1);
+    Display_.df_data = get_int ("DISPLAY_DF_INFO", 0, 1, 1);
     Display_.dr_data = get_int ("DISPLAY_DEAD_RECKONING_INFO", 0, 1, 1);
     Display_.dr_arc = get_int ("DISPLAY_DEAD_RECKONING_ARC", 0, 1, 1);
     Display_.dr_course = get_int ("DISPLAY_DEAD_RECKONING_COURSE", 0, 1, 1);
