@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xastir.h,v 1.53 2006/08/07 19:49:31 we7u Exp $
+ * $Id: xastir.h,v 1.55 2007/01/03 19:39:13 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2006  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -163,7 +163,7 @@ extern int index_maps_on_startup;
 #define FONT_DEFAULT FONT_MEDIUM
 extern char rotated_label_fontname[FONT_MAX][MAX_LABEL_FONTNAME];
 
-#ifdef HAVE_IMAGEMAGICK  //N0VH
+#ifdef HAVE_MAGICK  //N0VH
 extern int tiger_show_grid;
 extern int tiger_show_counties;
 extern int tiger_show_cities;
@@ -178,7 +178,7 @@ extern int tiger_show_statehwy;
 extern int tiger_show_water;
 extern int tiger_show_lakes;
 extern int tiger_show_misc;
-#endif  // HAVE_IMAGEMAGICK
+#endif  // HAVE_MAGICK
 
 #ifdef HAVE_LIBGEOTIFF
 extern int DRG_XOR_colors;
